dateOfBirth property
The customer's date of birth in a format suitable for the API (optional).
Implementation
@JsonKey(name: "dateOfBirth")
String? dateOfBirth;
The customer's date of birth in a format suitable for the API (optional).
@JsonKey(name: "dateOfBirth")
String? dateOfBirth;