joinDate property
The customer's join date in a format suitable for the API (optional).
Implementation
@JsonKey(name: "joinDate")
String? joinDate;
The customer's join date in a format suitable for the API (optional).
@JsonKey(name: "joinDate")
String? joinDate;