CustomerAttributesBuilder class
Builder for CustomerAttributes.
Allows constructing attribute objects using a fluent API.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAdditionalAttribute(
String key, String value) → CustomerAttributesBuilder -
addCustomAttribute(
String key, String value) → CustomerAttributesBuilder -
additionalAttributes(
Map< String, String> ? attrs) → CustomerAttributesBuilder -
build(
) → CustomerAttributes -
customAttributes(
Map< String, String> ? attrs) → CustomerAttributesBuilder -
dateOfBirth(
String? dateOfBirth) → CustomerAttributesBuilder -
displayName(
String? displayName) → CustomerAttributesBuilder -
email(
String? email) → CustomerAttributesBuilder -
firstName(
String? firstName) → CustomerAttributesBuilder -
gender(
String? gender) → CustomerAttributesBuilder -
joinDate(
String? joinDate) → CustomerAttributesBuilder -
lastName(
String? lastName) → CustomerAttributesBuilder -
mobile(
String? mobile) → CustomerAttributesBuilder -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preferredLanguage(
String? preferredLanguage) → CustomerAttributesBuilder -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited