customerId property
The unique identifier of the customer associated with the event.
Implementation
@JsonKey(name: "customerId")
String customerId;
The unique identifier of the customer associated with the event.
@JsonKey(name: "customerId")
String customerId;