events property
A map containing the actual event data. The key represents the event type, and the value is a map containing additional event-specific data.
Implementation
@JsonKey(name: "events")
Map<String, Map<String, Object>> events;
A map containing the actual event data. The key represents the event type, and the value is a map containing additional event-specific data.
@JsonKey(name: "events")
Map<String, Map<String, Object>> events;