EventBuilder class

Builder for Event.

Constructors

EventBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Event
customerId(String id) EventBuilder
email(String? email) EventBuilder
eventMetaData(String key, Object value) EventBuilder
Adds metadata for the current event name. Event name must be set before calling this method.
eventName(String? eventName) EventBuilder
Sets the current event name. Must be called before adding metadata.
mobile(String? mobile) EventBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited