email property
The customer's email address (optional).
You can include the customer's email address if you plan to use email-based communication or for other purposes within your application.
Implementation
@JsonKey(name: "email")
final String? email;