pushProvider method
Specify the push provider used to obtain the device token.
Implementation
InitializeCustomerRequestBuilder pushProvider(PushProvider? provider) {
_pushProvider = provider;
return this;
}
Specify the push provider used to obtain the device token.
InitializeCustomerRequestBuilder pushProvider(PushProvider? provider) {
_pushProvider = provider;
return this;
}