PlayerRegisterRequest class

Represents the data structure for a player registration request to the Gameball API.

This class defines the properties required to register a player with the Gameball platform. It includes essential information for identifying the player, as well as optional details to enrich their profile and personalize their experience.

Annotations
  • @JsonSerializable.new()

Constructors

PlayerRegisterRequest({required String playerUniqueID, required String deviceToken, String? osType, PlayerAttributes? playerAttributes, String? referrerCode, String? email, String? mobileNumber})
Creates a new PlayerRegisterRequest object.
PlayerRegisterRequest.fromJson(Map<String, dynamic> json)
factory

Properties

deviceToken String
The player's device token for push notifications (required).
getter/setter pair
email String?
The player's email address (optional).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mobileNumber String?
The player's mobile number (optional).
getter/setter pair
osType String?
The operating system type of the player's device (optional, automatically set).
getter/setter pair
playerAttributes PlayerAttributes?
Additional player attributes to be sent during registration (optional).
getter/setter pair
playerUniqueID String
The unique identifier for the player (required).
getter/setter pair
referrerCode String?
A referral code associated with the player (optional).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the PlayerRegisterRequest object to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited