email property

  1. @JsonKey.new(name: "email")
String? email
getter/setter pair

The player's email address (optional).

You can include the player's email address if you plan to use email-based communication or for other purposes within your application.

Implementation

@JsonKey(name: "email")
String? email;