playerUniqueID property

  1. @JsonKey.new(name: "playerUniqueId")
String playerUniqueID
getter/setter pair

The unique identifier for the player (required).

This ID should uniquely identify the player within your application and persist across device changes or app reinstalls. You are responsible for generating and managing this unique ID.

Implementation

@JsonKey(name: "playerUniqueId")
String playerUniqueID;