ShowProfileRequest class
Represents the parameters for showing the Gameball profile.
This class encapsulates all the parameters needed to display the customer profile widget with customizable options for navigation and detail views.
- Annotations
-
- @JsonSerializable.new(createFactory: false)
Constructors
-
ShowProfileRequest.fromJson(Map<
String, dynamic> json) -
Create from JSON map.
factory
Properties
- closeButtonColor → String?
-
An optional color for the close button.
final
- customerId → String?
-
The unique identifier for the customer (optional for guest view).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
An optional flag to indicate if the navigation bar should be hidden.
final
- openDetail → String?
-
An optional URL to open within the profile.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool?
-
An optional flag to control the visibility of a close button.
final
- widgetUrlPrefix → String?
-
An optional custom URL prefix for the widget.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the
ShowProfileRequestobject to a JSON map. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited