hideNavigation property
An optional flag to indicate if the navigation bar should be hidden.
Implementation
@JsonKey(name: "hideNavigation")
final bool? hideNavigation;
An optional flag to indicate if the navigation bar should be hidden.
@JsonKey(name: "hideNavigation")
final bool? hideNavigation;