showCloseButton property
An optional flag to control the visibility of a close button.
Implementation
@JsonKey(name: "showCloseButton")
final bool? showCloseButton;
An optional flag to control the visibility of a close button.
@JsonKey(name: "showCloseButton")
final bool? showCloseButton;