SendEventCallback typedef
Callback function type for event sending responses.
Defines the signature for a callback function that handles the result of sending an event.
Arguments:
status: A boolean indicating whether the event was sent successfully.error: AnExceptionobject if an error occurred.
Implementation
typedef SendEventCallback = void Function(bool? status, Exception? error);