CustomerAttributes class
Represents additional customer attributes to be sent during registration.
This class defines various optional customer attributes that can be included with the customer registration request. These attributes can be used to personalize the customer's experience within the Gameball platform.
- Annotations
-
- @JsonSerializable.new(createFactory: false)
Constructors
-
CustomerAttributes.fromJson(Map<
String, dynamic> json) -
Create from JSON map.
factory
Properties
-
additionalAttributes
→ Map<
String, String> ? -
A map containing additional attributes that are not serialized to JSON.
These attributes can be used for internal processing.
final
- channel → String
-
The channel through which the customer joined (defaults to "mobile").
final
-
customAttributes
→ Map<
String, String> ? -
A map containing additional custom customer attributes (optional).
final
- dateOfBirth → String?
-
The customer's date of birth in a format suitable for the API (optional).
final
- displayName → String?
-
The customer's display name (optional).
final
- email → String?
-
The customer's email address (optional).
final
- firstName → String?
-
The customer's first name (optional).
final
- gender → String?
-
The customer's gender (optional).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinDate → String?
-
The customer's join date in a format suitable for the API (optional).
final
- lastName → String?
-
The customer's last name (optional).
final
- mobile → String?
-
The customer's mobile number (optional).
final
- preferredLanguage → String?
-
The customer's preferred language (optional).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? displayName, String? firstName, String? lastName, String? email, String? gender, String? mobile, String? dateOfBirth, String? joinDate, String? preferredLanguage, Map< String, String> ? customAttributes, Map<String, String> ? additionalAttributes}) → CustomerAttributes - Creates a copy with updated values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the
CustomerAttributesobject to a JSON map. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited