Event class
Represents an event to be sent to the Gameball API.
This class defines the structure of an event object with properties for event data, player unique ID, optional mobile number, and optional email.
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- email ↔ String?
-
The player's email address (optional).
getter/setter pair
-
events
↔ Map<
String, Map< String, Object> > -
A map containing the actual event data.
The key represents the event type, and the value is a map containing additional event-specific data.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileNumber ↔ String?
-
The player's mobile number (optional).
getter/setter pair
- playerUniqueId ↔ String
-
The unique identifier of the player associated with the event.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the
Eventobject to a JSON map. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited