InitializeCustomerRequest constructor
InitializeCustomerRequest({})
Creates a new InitializeCustomerRequest object.
Arguments:
customerId(required): The unique identifier for the customer.deviceToken(required): The customer's device token.osType(optional): The operating system type. Automatically set based on the platform if not provided.customerAttributes(optional): Additional attributes related to the customer.referrerCode(optional): A referral code associated with the customer.email(optional): The customer's email address.mobileNumber(optional): The customer's mobile number for communication purposes.isGuest(optional): A flag indicating if the customer is a guest or not.
Implementation
InitializeCustomerRequest({
required this.customerId,
required this.deviceToken,
this.osType,
this.customerAttributes,
this.referrerCode,
this.email,
this.mobileNumber,
this.isGuest,
this.pushProvider
}) {
osType = getDevicePlatform(); // Automatically set osType based on platform
}