customerId property
The unique identifier for the customer (required).
This identifier should uniquely identify the customer within your application and persist across device changes or app re-installs. You are responsible for generating and managing this unique Id.
Implementation
@JsonKey(name: "customerId")
String customerId;