mobile property
The customer's mobile number (optional).
You can include the customer's mobile number if you plan to use SMS-based communication or for other purposes within your application.
Implementation
@JsonKey(name: "mobile")
final String? mobile;