referrerCode property
A referral code associated with the customer (optional).
If a referral code is provided, it can be used to track referrals and potentially offer rewards to both the referring and referred customers.
Implementation
@JsonKey(name: "referrerCode")
String? referrerCode;