toJson method
Converts the InitializeCustomerRequest object to a JSON map.
This method is typically used internally by the json_serializable package
to serialize the object before sending it to the Gameball API.
Implementation
Map<String, dynamic> toJson() => _$InitializeCustomerRequestToJson(this);