email property
The player's email address (optional).
You can include the player's email address if you plan to use email-based communication or for other purposes within your application.
Implementation
@JsonKey(name: "email")
String? email;
The player's email address (optional).
You can include the player's email address if you plan to use email-based communication or for other purposes within your application.
@JsonKey(name: "email")
String? email;