ShowProfileRequest class
Represents the parameters for showing the Gameball profile.
This class encapsulates all the parameters needed to display the customer profile widget with customizable options for navigation and detail views.
- Annotations
-
- @JsonSerializable.new(createFactory: false)
Constructors
-
ShowProfileRequest.fromJson(Map<
String, dynamic> json) -
Create from JSON map.
factory
Properties
- closeButtonColor → String?
-
An optional color for the close button.
final
- customerId → String?
-
The unique identifier for the customer (optional for guest view).
final
- email → String?
-
An optional customer email address.
final
- externalLinkCallback → void Function(String url)?
-
Optional handler for links tagged gbExternalBrowser=true. When provided, the link is
delegated to this callback instead of being opened by the SDK in the system browser.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
An optional flag to indicate if the navigation bar should be hidden.
final
- mobile → String?
-
An optional customer mobile number.
final
- openDetail → String?
-
An optional URL to open within the profile.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool?
-
An optional flag to control the visibility of a close button.
final
-
widgetEventCallback
→ void Function(Map<
String, dynamic> ? event, Exception? error)? -
Optional handler that receives widget events posted from the widget webview via
window.WidgetEvent.postEvent as a {type, metadata} map; receives (null, error) when the
event payload can't be parsed.
final
- widgetUrlPrefix → String?
-
An optional custom URL prefix for the widget.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the
ShowProfileRequestobject to a JSON map. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited