ShowProfileRequestBuilder class
Builder class for ShowProfileRequest.
Provides a fluent API for constructing ShowProfileRequest instances.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → ShowProfileRequest - Build the final immutable ShowProfileRequest instance.
-
closeButtonColor(
String? closeButtonColor) → ShowProfileRequestBuilder - Set the optional close button color.
-
customerId(
String? customerId) → ShowProfileRequestBuilder - Set the optional customer id.
-
email(
String? email) → ShowProfileRequestBuilder - Set the optional customer email address.
-
externalLinkCallback(
void externalLinkCallback(String url)?) → ShowProfileRequestBuilder - Set the optional handler for links tagged gbExternalBrowser=true.
- Set whether to hide navigation.
-
mobile(
String? mobile) → ShowProfileRequestBuilder - Set the optional customer mobile number.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openDetail(
String? openDetail) → ShowProfileRequestBuilder - Set the optional detail URL to open.
-
showCloseButton(
bool? showCloseButton) → ShowProfileRequestBuilder - Set whether to show close button.
-
toString(
) → String -
A string representation of this object.
inherited
-
widgetEventCallback(
void widgetEventCallback(Map< String, dynamic> ? event, Exception? error)?) → ShowProfileRequestBuilder - Register a listener that receives widget events (e.g. game completion) as a {type, metadata} map, posted from the widget via window.WidgetEvent.postEvent.
-
widgetUrlPrefix(
String? widgetUrlPrefix) → ShowProfileRequestBuilder - Set the optional custom widget URL prefix.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited